========
Robotica
========


.. image:: https://img.shields.io/pypi/v/robotica.svg
        :target: https://pypi.python.org/pypi/robotica

.. image:: https://img.shields.io/travis/brianmay/robotica.svg
        :target: https://travis-ci.org/brianmay/robotica

.. image:: https://readthedocs.org/projects/robotica/badge/?version=latest
        :target: https://robotica.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/brianmay/robotica/shield.svg
     :target: https://pyup.io/repos/github/brianmay/robotica/
     :alt: Updates


Robotic maid to scare innocent children


* Free software: GNU General Public License v3
* Documentation: https://robotica.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

